@@ -1,7 +1,7 @@
 package App::Ikachan;
 use strict;
 use warnings;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 1;
 __END__
@@ -48,6 +48,10 @@ irc server password
 
 irc nickname
 
+=item -U, --User
+
+irc user name
+
 =item -r, --reverse-proxy
 
 treat X-Forwarded-For as REMOTE_ADDR if REMOTE_ADDR match this argument.
